@@ -30,7 +30,6 @@
 (custom-add-loads 'verilog-mode '("verilog-mode"))
 (custom-add-loads 'ruby-inferior-mode '("inf-ruby"))
 (custom-add-loads 'cperl '("cperl-mode"))
-(custom-add-loads 'makefile-mode '("make-mode"))
 (custom-add-loads 'icon '("icon"))
 (custom-add-loads 'compilation-elisp '("mode-compile"))
 (custom-add-loads 'diff-mode '("diff-mode"))
@@ -57,6 +56,7 @@
 (custom-add-loads 'compilation '("mode-compile"))
 (custom-add-loads 'p4 '("p4"))
 (custom-add-loads 'python '("python-mode"))
+(custom-add-loads 'makefile '("make-mode"))
 (custom-add-loads 'cperl-faces '("cperl-mode"))
 (custom-add-loads 'eiffel-indent '("eiffel"))
 (custom-add-loads 'verilog-mode-indent '("verilog-mode"))
